@@ -455,9 +455,9 @@ enum {
   SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE_CLASS,
   SPVM_NATIVE_C_BASIC_TYPE_ID_BOOL_CLASS,
   SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_CLASS,
-  SPVM_NATIVE_C_BASIC_TYPE_ID_COMMAND_INFO_CLASS,
   SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS,
   SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS,
+  SPVM_NATIVE_C_BASIC_TYPE_ID_COMMAND_INFO_CLASS,
   SPVM_NATIVE_C_BASIC_TYPE_ID_ADDRESS_CLASS,
 };
 
@@ -474,12 +474,6 @@ enum {
   SPVM_NATIVE_C_BASIC_TYPE_CATEGORY_ANY_OBJECT,
 };
 
-enum {
-  SPVM_NATIVE_C_CLASS_ID_ERROR = 1,
-  SPVM_NATIVE_C_CLASS_ID_ERROR_SYSTEM = 2,
-  SPVM_NATIVE_C_CLASS_ID_ERROR_NOT_SUPPORTED = 3,
-};
-
 enum {
   SPVM_NATIVE_C_TYPE_FLAG_REF = 1,
   SPVM_NATIVE_C_TYPE_FLAG_MUTABLE = 2,
