@@ -100,6 +100,7 @@
 
 
 enum {
+  SPVM_OPCODE_C_ID_END_ARGS,
   SPVM_OPCODE_C_ID_END_METHOD,
   SPVM_OPCODE_C_ID_GOTO,
   SPVM_OPCODE_C_ID_IF_EQ_ZERO,
@@ -109,33 +110,28 @@ enum {
   SPVM_OPCODE_C_ID_ENTER_SCOPE,
   SPVM_OPCODE_C_ID_PUSH_MORTAL,
   SPVM_OPCODE_C_ID_LEAVE_SCOPE,
-  SPVM_OPCODE_C_ID_INIT_BYTE,
-  SPVM_OPCODE_C_ID_INIT_SHORT,
-  SPVM_OPCODE_C_ID_INIT_INT,
-  SPVM_OPCODE_C_ID_INIT_LONG,
-  SPVM_OPCODE_C_ID_INIT_FLOAT,
-  SPVM_OPCODE_C_ID_INIT_DOUBLE,
-  SPVM_OPCODE_C_ID_INIT_OBJECT,
-  SPVM_OPCODE_C_ID_INIT_MULNUM_BYTE,
-  SPVM_OPCODE_C_ID_INIT_MULNUM_SHORT,
-  SPVM_OPCODE_C_ID_INIT_MULNUM_INT,
-  SPVM_OPCODE_C_ID_INIT_MULNUM_LONG,
-  SPVM_OPCODE_C_ID_INIT_MULNUM_FLOAT,
-  SPVM_OPCODE_C_ID_INIT_MULNUM_DOUBLE,
   SPVM_OPCODE_C_ID_MOVE_CONSTANT_BYTE,
   SPVM_OPCODE_C_ID_MOVE_CONSTANT_INT,
   SPVM_OPCODE_C_ID_MOVE_CONSTANT_LONG,
   SPVM_OPCODE_C_ID_MOVE_CONSTANT_FLOAT,
   SPVM_OPCODE_C_ID_MOVE_CONSTANT_DOUBLE,
   SPVM_OPCODE_C_ID_MOVE_BYTE,
+  SPVM_OPCODE_C_ID_MOVE_BYTE_ZERO,
   SPVM_OPCODE_C_ID_MOVE_SHORT,
+  SPVM_OPCODE_C_ID_MOVE_SHORT_ZERO,
   SPVM_OPCODE_C_ID_MOVE_INT,
+  SPVM_OPCODE_C_ID_MOVE_INT_ZERO,
   SPVM_OPCODE_C_ID_MOVE_LONG,
+  SPVM_OPCODE_C_ID_MOVE_LONG_ZERO,
   SPVM_OPCODE_C_ID_MOVE_FLOAT,
+  SPVM_OPCODE_C_ID_MOVE_FLOAT_ZERO,
   SPVM_OPCODE_C_ID_MOVE_DOUBLE,
+  SPVM_OPCODE_C_ID_MOVE_DOUBLE_ZERO,
   SPVM_OPCODE_C_ID_MOVE_OBJECT,
+  SPVM_OPCODE_C_ID_MOVE_OBJECT_UNDEF,
   SPVM_OPCODE_C_ID_MOVE_OBJECT_WITH_TYPE_CHECKING,
   SPVM_OPCODE_C_ID_MOVE_OBJECT_CHECK_READ_ONLY,
+  SPVM_OPCODE_C_ID_MOVE_OBJECT_NO_INC,
   SPVM_OPCODE_C_ID_MOVE_REF,
   SPVM_OPCODE_C_ID_ADD_INT,
   SPVM_OPCODE_C_ID_ADD_LONG,
@@ -290,8 +286,8 @@ enum {
   SPVM_OPCODE_C_ID_GET_EXCEPTION_VAR,
   SPVM_OPCODE_C_ID_SET_EXCEPTION_VAR,
   SPVM_OPCODE_C_ID_SET_EXCEPTION_VAR_UNDEF,
-  SPVM_OPCODE_C_ID_IF_EXCEPTION_CATCH,
-  SPVM_OPCODE_C_ID_IF_EXCEPTION_RETURN,
+  SPVM_OPCODE_C_ID_GOTO_END_OF_EVAL_ON_EXCEPTION,
+  SPVM_OPCODE_C_ID_GOTO_END_OF_METHOD_ON_EXCEPTION,
   SPVM_OPCODE_C_ID_ISA,
   SPVM_OPCODE_C_ID_IS_TYPE,
   SPVM_OPCODE_C_ID_CAN,
@@ -299,13 +295,15 @@ enum {
   SPVM_OPCODE_C_ID_SAY,
   SPVM_OPCODE_C_ID_WARN,
   SPVM_OPCODE_C_ID_DIE,
-  SPVM_OPCODE_C_ID_GET_ERROR_CODE,
-  SPVM_OPCODE_C_ID_SET_ERROR_CODE,
-  SPVM_OPCODE_C_ID_CLEAR_EVAL_ERROR, // The operator doesn't exist
-  SPVM_OPCODE_C_ID_GET_EVAL_ERROR,
+  SPVM_OPCODE_C_ID_GET_DIE_ERROR_ID,
+  SPVM_OPCODE_C_ID_SET_DIE_ERROR_ID,
+  SPVM_OPCODE_C_ID_CLEAR_EVAL_ERROR_ID,
+  SPVM_OPCODE_C_ID_GET_EVAL_ERROR_ID,
+  SPVM_OPCODE_C_ID_SET_EVAL_ERROR_ID,
   SPVM_OPCODE_C_ID_GET_CLASS_ID,
-  SPVM_OPCODE_C_ID_SET_ERROR, // The operator doesn't exist
-  SPVM_OPCODE_C_ID_REFOP,
+  SPVM_OPCODE_C_ID_GET_BASIC_TYPE_ID,
+  SPVM_OPCODE_C_ID_SET_ERROR_ID,
+  SPVM_OPCODE_C_ID_TYPE_NAME,
   SPVM_OPCODE_C_ID_DUMP,
   SPVM_OPCODE_C_ID_COPY,
   SPVM_OPCODE_C_ID_REF,
@@ -340,11 +338,17 @@ enum {
   SPVM_OPCODE_C_ID_SET_MULNUM_FIELD_FLOAT,
   SPVM_OPCODE_C_ID_SET_MULNUM_FIELD_DOUBLE,
   SPVM_OPCODE_C_ID_MOVE_MULNUM_BYTE,
+  SPVM_OPCODE_C_ID_MOVE_MULNUM_BYTE_ZERO,
   SPVM_OPCODE_C_ID_MOVE_MULNUM_SHORT,
+  SPVM_OPCODE_C_ID_MOVE_MULNUM_SHORT_ZERO,
   SPVM_OPCODE_C_ID_MOVE_MULNUM_INT,
+  SPVM_OPCODE_C_ID_MOVE_MULNUM_INT_ZERO,
   SPVM_OPCODE_C_ID_MOVE_MULNUM_LONG,
+  SPVM_OPCODE_C_ID_MOVE_MULNUM_LONG_ZERO,
   SPVM_OPCODE_C_ID_MOVE_MULNUM_FLOAT,
+  SPVM_OPCODE_C_ID_MOVE_MULNUM_FLOAT_ZERO,
   SPVM_OPCODE_C_ID_MOVE_MULNUM_DOUBLE,
+  SPVM_OPCODE_C_ID_MOVE_MULNUM_DOUBLE_ZERO,
   SPVM_OPCODE_C_ID_GET_MULNUM_ARRAY_BYTE,
   SPVM_OPCODE_C_ID_GET_MULNUM_ARRAY_SHORT,
   SPVM_OPCODE_C_ID_GET_MULNUM_ARRAY_INT,
@@ -390,7 +394,6 @@ enum {
   SPVM_OPCODE_C_ID_WEAKEN_FIELD,
   SPVM_OPCODE_C_ID_UNWEAKEN_FIELD,
   SPVM_OPCODE_C_ID_ISWEAK_FIELD,
-  SPVM_OPCODE_C_ID_REFCNT,
   SPVM_OPCODE_C_ID_TYPE_CONVERSION_BYTE_TO_SHORT,
   SPVM_OPCODE_C_ID_TYPE_CONVERSION_BYTE_TO_INT,
   SPVM_OPCODE_C_ID_TYPE_CONVERSION_BYTE_TO_LONG,
@@ -494,8 +497,8 @@ enum {
   SPVM_OPCODE_C_ID_RETURN_MULNUM_DOUBLE,
   SPVM_OPCODE_C_ID_ITEMS,
   SPVM_OPCODE_C_ID_CALL_CLASS_METHOD,
+  SPVM_OPCODE_C_ID_CALL_INSTANCE_METHOD_STATIC,
   SPVM_OPCODE_C_ID_CALL_INSTANCE_METHOD,
-  SPVM_OPCODE_C_ID_CALL_INTERFACE_METHOD,
 };
 
 // An operation code is 128 bits
