@@ -61,111 +61,109 @@ extern int SPVM_yydebug;
     ATTRIBUTE = 271,
     MAKE_READ_ONLY = 272,
     INTERFACE = 273,
-    ERROR_CODE = 274,
-    ERROR = 275,
-    ITEMS = 276,
-    VERSION_DECL = 277,
-    IF = 278,
-    UNLESS = 279,
-    ELSIF = 280,
-    ELSE = 281,
-    FOR = 282,
-    WHILE = 283,
-    LAST = 284,
-    NEXT = 285,
-    SWITCH = 286,
-    CASE = 287,
-    DEFAULT = 288,
-    BREAK = 289,
-    EVAL = 290,
-    SYMBOL_NAME = 291,
-    VAR_NAME = 292,
-    CONSTANT = 293,
-    EXCEPTION_VAR = 294,
-    UNDEF = 295,
-    VOID = 296,
-    BYTE = 297,
-    SHORT = 298,
-    INT = 299,
-    LONG = 300,
-    FLOAT = 301,
-    DOUBLE = 302,
-    STRING = 303,
-    OBJECT = 304,
-    TRUE = 305,
-    FALSE = 306,
-    END_OF_FILE = 307,
-    FATCAMMA = 308,
-    RW = 309,
-    RO = 310,
-    WO = 311,
-    INIT = 312,
-    NEW = 313,
-    OF = 314,
-    CLASS_ID = 315,
-    EXTENDS = 316,
-    SUPER = 317,
-    RETURN = 318,
-    WEAKEN = 319,
-    DIE = 320,
-    WARN = 321,
-    PRINT = 322,
-    SAY = 323,
-    CURRENT_CLASS_NAME = 324,
-    UNWEAKEN = 325,
-    ASSIGN = 326,
-    SPECIAL_ASSIGN = 327,
-    LOGICAL_OR = 328,
-    LOGICAL_AND = 329,
-    BIT_OR = 330,
-    BIT_XOR = 331,
-    BIT_AND = 332,
-    NUMEQ = 333,
-    NUMNE = 334,
-    STREQ = 335,
-    STRNE = 336,
-    NUMGT = 337,
-    NUMGE = 338,
-    NUMLT = 339,
-    NUMLE = 340,
-    STRGT = 341,
-    STRGE = 342,
-    STRLT = 343,
-    STRLE = 344,
-    ISA = 345,
-    IS_TYPE = 346,
-    IS_COMPILE_TYPE = 347,
-    NUMERIC_CMP = 348,
-    STRING_CMP = 349,
-    CAN = 350,
-    SHIFT = 351,
-    DIVIDE = 352,
-    DIVIDE_UNSIGNED_INT = 353,
-    DIVIDE_UNSIGNED_LONG = 354,
-    REMAINDER = 355,
-    REMAINDER_UNSIGNED_INT = 356,
-    REMAINDER_UNSIGNED_LONG = 357,
-    LOGICAL_NOT = 358,
-    BIT_NOT = 359,
-    CREATE_REF = 360,
-    DEREF = 361,
-    PLUS = 362,
-    MINUS = 363,
-    CONVERT = 364,
-    SCALAR = 365,
-    STRING_LENGTH = 366,
-    ISWEAK = 367,
-    REFCNT = 368,
-    TYPE_NAME = 369,
-    COMPILE_TYPE_NAME = 370,
-    DUMP = 371,
-    NEW_STRING_LEN = 372,
-    IS_READ_ONLY = 373,
-    COPY = 374,
-    SET_ERROR_CODE = 375,
-    INC = 376,
-    DEC = 377,
-    ARROW = 378
+    EVAL_ERROR_ID = 274,
+    ITEMS = 275,
+    VERSION_DECL = 276,
+    IF = 277,
+    UNLESS = 278,
+    ELSIF = 279,
+    ELSE = 280,
+    FOR = 281,
+    WHILE = 282,
+    LAST = 283,
+    NEXT = 284,
+    SWITCH = 285,
+    CASE = 286,
+    DEFAULT = 287,
+    BREAK = 288,
+    EVAL = 289,
+    SYMBOL_NAME = 290,
+    VAR_NAME = 291,
+    CONSTANT = 292,
+    EXCEPTION_VAR = 293,
+    UNDEF = 294,
+    VOID = 295,
+    BYTE = 296,
+    SHORT = 297,
+    INT = 298,
+    LONG = 299,
+    FLOAT = 300,
+    DOUBLE = 301,
+    STRING = 302,
+    OBJECT = 303,
+    TRUE = 304,
+    FALSE = 305,
+    END_OF_FILE = 306,
+    FATCAMMA = 307,
+    RW = 308,
+    RO = 309,
+    WO = 310,
+    INIT = 311,
+    NEW = 312,
+    OF = 313,
+    BASIC_TYPE_ID = 314,
+    EXTENDS = 315,
+    SUPER = 316,
+    RETURN = 317,
+    WEAKEN = 318,
+    DIE = 319,
+    WARN = 320,
+    PRINT = 321,
+    SAY = 322,
+    CURRENT_CLASS_NAME = 323,
+    UNWEAKEN = 324,
+    ASSIGN = 325,
+    SPECIAL_ASSIGN = 326,
+    LOGICAL_OR = 327,
+    LOGICAL_AND = 328,
+    BIT_OR = 329,
+    BIT_XOR = 330,
+    BIT_AND = 331,
+    NUMEQ = 332,
+    NUMNE = 333,
+    STREQ = 334,
+    STRNE = 335,
+    NUMGT = 336,
+    NUMGE = 337,
+    NUMLT = 338,
+    NUMLE = 339,
+    STRGT = 340,
+    STRGE = 341,
+    STRLT = 342,
+    STRLE = 343,
+    ISA = 344,
+    IS_TYPE = 345,
+    IS_COMPILE_TYPE = 346,
+    NUMERIC_CMP = 347,
+    STRING_CMP = 348,
+    CAN = 349,
+    SHIFT = 350,
+    DIVIDE = 351,
+    DIVIDE_UNSIGNED_INT = 352,
+    DIVIDE_UNSIGNED_LONG = 353,
+    REMAINDER = 354,
+    REMAINDER_UNSIGNED_INT = 355,
+    REMAINDER_UNSIGNED_LONG = 356,
+    LOGICAL_NOT = 357,
+    BIT_NOT = 358,
+    CREATE_REF = 359,
+    DEREF = 360,
+    PLUS = 361,
+    MINUS = 362,
+    CONVERT = 363,
+    SCALAR = 364,
+    STRING_LENGTH = 365,
+    ISWEAK = 366,
+    REFCNT = 367,
+    TYPE_NAME = 368,
+    COMPILE_TYPE_NAME = 369,
+    DUMP = 370,
+    NEW_STRING_LEN = 371,
+    IS_READ_ONLY = 372,
+    COPY = 373,
+    INC = 374,
+    DEC = 375,
+    ARROW = 376
   };
 #endif
 
