@@ -24,7 +24,7 @@
 #include "spvm_opcode.h"
 #include "spvm_basic_type.h"
 #include "spvm_use.h"
-#include "spvm_op_checker.h"
+#include "spvm_ast_checker.h"
 #include "spvm_opcode_builder.h"
 #include "spvm_object.h"
 #include "spvm_var_decl.h"
@@ -55,7 +55,7 @@ SPVM_COMPILER* SPVM_COMPILER_new() {
   SPVM_ALLOCATOR* allocator = SPVM_ALLOCATOR_new();
   compiler->allocator = allocator;
   
-  compiler->bufptr = "";
+  compiler->ch_ptr = "";
   
   compiler->constant_strings = SPVM_LIST_new_list_permanent(compiler->allocator, 128);
   compiler->constant_string_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 128);
@@ -75,68 +75,110 @@ SPVM_COMPILER* SPVM_COMPILER_new() {
   compiler->class_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
   compiler->class_vars = SPVM_LIST_new_list_permanent(compiler->allocator, 0);
   compiler->opcode_array = SPVM_OPCODE_ARRAY_new(compiler);
-  compiler->class_source_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
+  compiler->source_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
   compiler->switch_infos = SPVM_LIST_new_list_permanent(compiler->allocator, 0);
-  compiler->not_found_class_class_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
+  compiler->not_found_class_symtable = SPVM_HASH_new_hash_permanent(compiler->allocator, 0);
   
   // Add basic types
   SPVM_COMPILER_add_basic_types(compiler);
   
   // Add Bool source
-  const char* spvm_bool_class_source = "class Bool {\n  INIT {\n    $TRUE = new Bool;\n    $TRUE->{value} = 1;\n    $FALSE = new Bool;\n    $FALSE->{value} = 0;\n  }\n  \n  our $TRUE : ro Bool;\n  our $FALSE : ro Bool;\n  has value : ro int;\n}";
-  SPVM_HASH_set(compiler->class_source_symtable, "Bool", strlen("Bool"), (void*)spvm_bool_class_source);
+  {
+    const char* class_name = "Bool";
+    const char* source = "class Bool {\n  INIT {\n    $TRUE = new Bool;\n    $TRUE->{value} = 1;\n    $FALSE = new Bool;\n    $FALSE->{value} = 0;\n  }\n  \n  our $TRUE : ro Bool;\n  our $FALSE : ro Bool;\n  has value : ro int;\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+  }
   
   // Add Error source
-  const char* spvm_error_class_source = "class Error;";
-  SPVM_HASH_set(compiler->class_source_symtable, "Error", strlen("Error"), (void*)spvm_error_class_source);
+  {
+    const char* class_name = "Error";
+    const char* source = "class Error;";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+  }
   
   // Add Error::System source
-  const char* spvm_error_system_class_source = "class Error::System;";
-  SPVM_HASH_set(compiler->class_source_symtable, "Error::System", strlen("Error::System"), (void*)spvm_error_system_class_source);
+  {
+    const char* class_name = "Error::System";
+    const char* source = "class Error::System;";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+  }
   
   // Add Error::NotSupported source
-  const char* spvm_error_not_supported_class_source = "class Error::NotSupported;";
-  SPVM_HASH_set(compiler->class_source_symtable, "Error::NotSupported", strlen("Error::NotSupported"), (void*)spvm_error_not_supported_class_source);
-
+  {
+    const char* class_name = "Error::NotSupported";
+    const char* source = "class Error::NotSupported;";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+  }
+  
   // Add Byte source
-  const char* spvm_byte_class_source = "class Byte {\n  has value : rw byte;\n  static method new : Byte ($value : int) {\n    my $self = new Byte;\n    $self->{value} = (byte)$value;\n    return $self;\n  }\n}";
-  SPVM_HASH_set(compiler->class_source_symtable, "Byte", strlen("Byte"), (void*)spvm_byte_class_source);
+  {
+    const char* class_name = "Byte";
+    const char* source = "class Byte {\n  has value : ro byte;\n  static method new : Byte ($value : int) {\n    my $self = new Byte;\n    $self->{value} = (byte)$value;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+  }
   
   // Add Short source
-  const char* spvm_short_class_source = "class Short {\n  has value : rw short;\n  static method new : Short ($value : int) {\n    my $self = new Short;\n    $self->{value} = (short)$value;\n    return $self;\n  }\n}";
-  SPVM_HASH_set(compiler->class_source_symtable, "Short", strlen("Short"), (void*)spvm_short_class_source);
+  {
+    const char* class_name = "Short";
+    const char* source = "class Short {\n  has value : ro short;\n  static method new : Short ($value : int) {\n    my $self = new Short;\n    $self->{value} = (short)$value;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+  }
   
   // Add Int source
-  const char* spvm_int_class_source = "class Int {\n  has value : rw int;\n  static method new : Int ($value : int) {\n    my $self = new Int;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-  SPVM_HASH_set(compiler->class_source_symtable, "Int", strlen("Int"), (void*)spvm_int_class_source);
+  {
+    const char* class_name = "Int";
+    const char* source = "class Int {\n  has value : ro int;\n  static method new : Int ($value : int) {\n    my $self = new Int;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+  }
   
   // Add Long source
-  const char* spvm_long_class_source = "class Long {\n  has value : rw long;\n  static method new : Long ($value : long) {\n    my $self = new Long;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-  SPVM_HASH_set(compiler->class_source_symtable, "Long", strlen("Long"), (void*)spvm_long_class_source);
+  {
+    const char* class_name = "Long";
+    const char* source = "class Long {\n  has value : ro long;\n  static method new : Long ($value : long) {\n    my $self = new Long;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+  }
   
   // Add Float source
-  const char* spvm_float_class_source = "class Float {\n  has value : rw float;\n  static method new : Float ($value : float) {\n    my $self = new Float;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-  SPVM_HASH_set(compiler->class_source_symtable, "Float", strlen("Float"), (void*)spvm_float_class_source);
+  {
+    const char* class_name = "Float";
+    const char* source = "class Float {\n  has value : ro float;\n  static method new : Float ($value : float) {\n    my $self = new Float;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+  }
   
   // Add Double source
-  const char* spvm_double_class_source = "class Double {\n  has value : rw double;\n  static method new : Double ($value : double) {\n    my $self = new Double;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
-  SPVM_HASH_set(compiler->class_source_symtable, "Double", strlen("Double"), (void*)spvm_double_class_source);
+  {
+    const char* class_name = "Double";
+    const char* source = "class Double {\n  has value : ro double;\n  static method new : Double ($value : double) {\n    my $self = new Double;\n    $self->{value} = $value;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+  }
   
   // Add CommandInfo source
-  const char* spvm_command_info_class_source = "class CommandInfo {\n  our $PROGRAM_NAME : ro string;\n  our $ARGV : ro string[];\n  our $BASE_TIME : ro long;\n  }";
-  SPVM_HASH_set(compiler->class_source_symtable, "CommandInfo", strlen("CommandInfo"), (void*)spvm_command_info_class_source);
-
+  {
+    const char* class_name = "CommandInfo";
+    const char* source = "class CommandInfo {\n  our $PROGRAM_NAME : ro string;\n  our $ARGV : ro string[];\n  our $BASE_TIME : ro long;\n  }";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+  }
+  
   // Add Address source
-  const char* spvm_address_class_source = "class Address : pointer {\n  static method new : Address () {\n    my $self = new Address;\n    return $self;\n  }\n}";
-  SPVM_HASH_set(compiler->class_source_symtable, "Address", strlen("Address"), (void*)spvm_address_class_source);
+  {
+    const char* class_name = "Address";
+    const char* source = "class Address : pointer {\n  static method new : Address () {\n    my $self = new Address;\n    return $self;\n  }\n}";
+    SPVM_COMPILER_add_source(compiler, class_name, source, strlen(source));
+  }
   
   return compiler;
 }
 
+void SPVM_COMPILER_add_source(SPVM_COMPILER* compiler, const char* class_name, const char* source, int32_t length) {
+  SPVM_STRING_BUFFER* source_buffer = SPVM_STRING_BUFFER_new(compiler->allocator, length, SPVM_ALLOCATOR_C_ALLOC_TYPE_PERMANENT);
+  SPVM_STRING_BUFFER_add_len(source_buffer, (char*)source, strlen(source));
+  SPVM_HASH_set(compiler->source_symtable, class_name, strlen(class_name), (void*)source_buffer);
+}
+
 void SPVM_COMPILER_add_basic_type(SPVM_COMPILER* compiler, int32_t basic_type_id) {
    SPVM_BASIC_TYPE* basic_type = SPVM_BASIC_TYPE_new(compiler);
    basic_type->id = basic_type_id;
-   const char* basic_type_name_tmp = (SPVM_NATIVE_C_BASIC_TYPE_ID_NAMES())[basic_type->id];
+   const char* basic_type_name_tmp = (SPVM_BASIC_TYPE_C_ID_NAMES())[basic_type->id];
    SPVM_CONSTANT_STRING* basic_type_name_string = SPVM_CONSTANT_STRING_new(compiler, basic_type_name_tmp, strlen(basic_type_name_tmp));
    basic_type->name = basic_type_name_string->value;
    SPVM_LIST_push(compiler->basic_types, basic_type);
@@ -164,6 +206,10 @@ void SPVM_COMPILER_add_basic_types(SPVM_COMPILER* compiler) {
   SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_DOUBLE_CLASS);
   SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_BOOL_CLASS);
   SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_CLASS);
+  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_SYSTEM_CLASS);
+  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ERROR_NOT_SUPPORTED_CLASS);
+  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_COMMAND_INFO_CLASS);
+  SPVM_COMPILER_add_basic_type(compiler, SPVM_NATIVE_C_BASIC_TYPE_ID_ADDRESS_CLASS);
 }
 
 int32_t SPVM_COMPILER_get_error_messages_length(SPVM_COMPILER* compiler) {
@@ -242,7 +288,7 @@ int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name) {
   // Initialize error messages
   compiler->error_messages = SPVM_LIST_new_list_permanent(compiler->allocator, 0);
   
-  int32_t error_code = 0;
+  int32_t die_error_id = 0;
 
   int32_t compile_start_memory_blocks_count_tmp = compiler->allocator->memory_blocks_count_tmp;
 
@@ -268,17 +314,17 @@ int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name) {
   /* Tokenize and Parse */
   int32_t parse_error_flag = SPVM_yyparse(compiler);
   if (parse_error_flag) {
-    error_code = 1;
+    die_error_id = 1;
   }
   else {
     if (SPVM_COMPILER_get_error_messages_length(compiler) > 0) {
-      error_code = 2;
+      die_error_id = 2;
     }
     else {
       // Check syntax
-      SPVM_OP_CHECKER_check(compiler);
+      SPVM_AST_CHECKER_check(compiler);
       if (SPVM_COMPILER_get_error_messages_length(compiler) > 0) {
-        error_code = 3;
+        die_error_id = 3;
       }
       else {
         // Build operation code
@@ -286,7 +332,7 @@ int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name) {
         SPVM_OPCODE_BUILDER_build_opcode_array(compiler);
         assert(compiler->allocator->memory_blocks_count_tmp == build_opcode_array_start_memory_blocks_count_tmp);
         if (SPVM_COMPILER_get_error_messages_length(compiler) > 0) {
-          error_code = 4;
+          die_error_id = 4;
         }
       }
     }
@@ -396,7 +442,6 @@ int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name) {
         method->op_method = NULL;
         method->op_name = NULL;
         method->op_block = NULL;
-        method->op_inline = NULL;
       }
     }
   }
@@ -416,7 +461,7 @@ int32_t SPVM_COMPILER_compile(SPVM_COMPILER* compiler, const char* class_name) {
   
   assert(compiler->allocator->memory_blocks_count_tmp == compile_start_memory_blocks_count_tmp);
   
-  return error_code;
+  return die_error_id;
 }
 
 int32_t SPVM_COMPILER_calculate_runtime_codes_length(SPVM_COMPILER* compiler) {
@@ -656,6 +701,13 @@ int32_t* SPVM_COMPILER_create_runtime_codes(SPVM_COMPILER* compiler, SPVM_ALLOCA
       runtime_class->version_string_id = -1;
     }
     
+    if (class->init_method) {
+      runtime_class->init_method_id = class->init_method->id;
+    }
+    else {
+      runtime_class->init_method_id = -1;
+    }
+    
     if (class->destructor_method) {
       runtime_class->destructor_method_id = class->destructor_method->id;
     }
