@@ -100,6 +100,7 @@
 const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
 
   static const char* const id_names[] = {
+    "END_ARGS",
     "END_METHOD",
     "GOTO",
     "IF_EQ_ZERO",
@@ -109,33 +110,28 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "ENTER_SCOPE",
     "PUSH_MORTAL",
     "LEAVE_SCOPE",
-    "INIT_BYTE",
-    "INIT_SHORT",
-    "INIT_INT",
-    "INIT_LONG",
-    "INIT_FLOAT",
-    "INIT_DOUBLE",
-    "INIT_OBJECT",
-    "INIT_MULNUM_BYTE",
-    "INIT_MULNUM_SHORT",
-    "INIT_MULNUM_INT",
-    "INIT_MULNUM_LONG",
-    "INIT_MULNUM_FLOAT",
-    "INIT_MULNUM_DOUBLE",
     "MOVE_CONSTANT_BYTE",
     "MOVE_CONSTANT_INT",
     "MOVE_CONSTANT_LONG",
     "MOVE_CONSTANT_FLOAT",
     "MOVE_CONSTANT_DOUBLE",
     "MOVE_BYTE",
+    "MOVE_BYTE_ZERO",
     "MOVE_SHORT",
+    "MOVE_SHORT_ZERO",
     "MOVE_INT",
+    "MOVE_INT_ZERO",
     "MOVE_LONG",
+    "MOVE_LONG_ZERO",
     "MOVE_FLOAT",
+    "MOVE_FLOAT_ZERO",
     "MOVE_DOUBLE",
+    "MOVE_DOUBLE_ZERO",
     "MOVE_OBJECT",
+    "MOVE_OBJECT_UNDEF",
     "MOVE_OBJECT_CHECK_ASSIGN",
     "MOVE_OBJECT_CHECK_READ_ONLY",
+    "MOVE_OBJECT_NO_INC",
     "MOVE_REF",
     "ADD_INT",
     "ADD_LONG",
@@ -299,13 +295,15 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "SAY",
     "WARN",
     "DIE",
-    "GET_ERROR_CODE",
-    "SET_ERROR_CODE",
-    "CLEAR_EVAL_ERROR",
-    "GET_EVAL_ERROR",
+    "GET_DIE_ERROR_ID",
+    "SET_DIE_ERROR_ID",
+    "CLEAR_EVAL_ERROR_ID",
+    "GET_EVAL_ERROR_ID",
+    "SET_EVAL_ERROR_ID",
     "GET_CLASS_ID",
-    "SET_ERROR",
-    "REFOP",
+    "GET_BASIC_TYPE_ID",
+    "SET_ERROR_ID",
+    "TYPE_NAME",
     "DUMP",
     "COPY",
     "REF",
@@ -340,11 +338,17 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "SET_MULNUM_FIELD_FLOAT",
     "SET_MULNUM_FIELD_DOUBLE",
     "MOVE_MULNUM_BYTE",
+    "MOVE_MULNUM_BYTE_ZERO",
     "MOVE_MULNUM_SHORT",
+    "MOVE_MULNUM_SHORT_ZERO",
     "MOVE_MULNUM_INT",
+    "MOVE_MULNUM_INT_ZERO",
     "MOVE_MULNUM_LONG",
+    "MOVE_MULNUM_LONG_ZERO",
     "MOVE_MULNUM_FLOAT",
+    "MOVE_MULNUM_FLOAT_ZERO",
     "MOVE_MULNUM_DOUBLE",
+    "MOVE_MULNUM_DOUBLE_ZERO",
     "GET_MULNUM_ARRAY_BYTE",
     "GET_MULNUM_ARRAY_SHORT",
     "GET_MULNUM_ARRAY_INT",
@@ -390,7 +394,6 @@ const char* const* SPVM_OPCODE_C_ID_NAMES(void) {
     "WEAKEN_FIELD",
     "UNWEAKEN_FIELD",
     "ISWEAK_FIELD",
-    "REFCNT",
     "TYPE_CONVERSION_BYTE_TO_SHORT",
     "TYPE_CONVERSION_BYTE_TO_INT",
     "TYPE_CONVERSION_BYTE_TO_LONG",
