@@ -65,7 +65,7 @@ Creates a new L<Immutable::StringList|SPVM::Immutable::StringList> object with t
 
 Exceptions:
 
-The $length must be greater than or equal to 0. Otherwize an exception is thrown.
+The $length must be greater than or equal to 0. Otherwise an exception is thrown.
 
 =head1 Instance Methods
 
@@ -77,9 +77,9 @@ Gets the element of the position of the $index.
 
 Exceptions:
 
-The $index must be greater than or equal to 0. Otherwize an exception is thrown.
+The $index must be greater than or equal to 0. Otherwise an exception is thrown.
 
-The $index must be less than the length of the $list. Otherwize an exception is thrown.
+The $index must be less than the length of the $list. Otherwise an exception is thrown.
 
 =head2 to_array
 
